r"""
Scrape Scryfall set data!

Documentation: https://scryfall.com/docs/api/sets
:
"""
from .functions import (
    scrape_by_code,
    scrape_by_scryfall_id,
    scrape_all_sets,
    scrape_by_tcgplayer_id,
)
